@@ -34,9 +34,9 @@ struct addrxlat_result {
 
 struct addrxlat_result addrxlat_siit64(struct xlator *instance,
 		struct in6_addr *in, struct result_addrxlat64 *out,
-		bool enable_blacklists);
+		bool enable_denylists);
 struct addrxlat_result addrxlat_siit46(struct xlator *instance,
 		__be32 in, struct result_addrxlat46 *out,
-		bool enable_eam, bool enable_blacklists);
+		bool enable_eam, bool enable_denylists);
 
 #endif /* SRC_MOD_COMMON_ADDRESS_XLAT_H_ */
