@@ -5,6 +5,7 @@
 #include <linux/slab.h>
 
 #include "common/types.h"
+#include "mod/common/linux_version.h"
 #include "mod/common/log.h"
 #include "mod/common/wkmalloc.h"
 #include "mod/common/db/rbtree.h"
@@ -530,9 +531,31 @@ static int add_to_addr_tree(struct pool4 *pool,
 	return 0;
 }
 
-int pool4db_add(struct pool4 *pool, const struct pool4_entry *entry)
+static int
+get_min_eph(struct local_ports *ports)
+{
+#if LINUX_VERSION_AT_LEAST(6, 8, 0, 9999, 9)
+	return ports->range & 0xFFFFu;
+#else
+	return ports->range[0];
+#endif
+}
+
+static int
+get_max_eph(struct local_ports *ports)
+{
+#if LINUX_VERSION_AT_LEAST(6, 8, 0, 9999, 9)
+	return (ports->range >> 16u) & 0xFFFFu;
+#else
+	return ports->range[1];
+#endif
+}
+
+int pool4db_add(struct pool4 *pool, const struct pool4_entry *entry,
+		struct net *ns, bool force)
 {
 	struct ipv4_range addend = { .ports = entry->range.ports };
+	int eph_min, eph_max;
 	u64 tmp;
 	int error;
 
@@ -545,10 +568,26 @@ int pool4db_add(struct pool4 *pool, const struct pool4_entry *entry)
 
 	if (addend.ports.min > addend.ports.max)
 		swap(addend.ports.min, addend.ports.max);
-	if (entry->proto == L4PROTO_TCP || entry->proto == L4PROTO_UDP)
+	if (entry->proto == L4PROTO_TCP || entry->proto == L4PROTO_UDP) {
 		if (addend.ports.min == 0)
 			addend.ports.min = 1;
 
+		if (!force && ns) {
+			eph_min = get_min_eph(&ns->ipv4.ip_local_ports);
+			eph_max = get_max_eph(&ns->ipv4.ip_local_ports);
+			if (addend.ports.max >= eph_min &&
+			    eph_max >= addend.ports.min) {
+				log_err("Port range %u-%u intersects with the namespace's ephemeral range (%d-%d).\n"
+					"Please read https://nicmx.github.io/Jool/en/usr-flags-pool4.html#port-range\n"
+					"Rejecting request; add --force to skip this validation.",
+					addend.ports.min, addend.ports.max,
+					eph_min, eph_max);
+				return -EINVAL;
+			}
+
+		}
+	}
+
 	addend.prefix.len = 32;
 	foreach_addr4(addend.prefix.addr, tmp, &entry->range.prefix) {
 		spin_lock_bh(&pool->lock);
