@@ -203,7 +203,11 @@ static verdict compute_flowix64(struct xlation *state)
 	hdr6 = pkt_ip6_hdr(&state->in);
 
 	flow4->flowi4_mark = state->in.skb->mark;
+#if LINUX_VERSION_AT_LEAST(6, 18, 0, 9999, 0)
+	flow4->flowi4_dscp = xlat_tos(&state->jool.globals, hdr6);
+#else
 	flow4->flowi4_tos = xlat_tos(&state->jool.globals, hdr6);
+#endif
 	flow4->flowi4_scope = RT_SCOPE_UNIVERSE;
 	flow4->flowi4_proto = xlat_proto(hdr6);
 	/*
@@ -391,8 +395,8 @@ static int fragment_exceeds_mtu64(struct packet const *in, unsigned int mtu)
 		goto generic_too_big;
 
 	/*
-	 * TODO (performance) This loop could probably be optimized away by
-	 * querying IP6CB(skb)->frag_max_size. You'll have to test it.
+	 * IP6CB(skb)->frag_max_size is sometimes uninitialized despite
+	 * fragmentation; don't trust it.
 	 */
 	mtu -= sizeof(struct iphdr);
 	skb_walk_frags(in->skb, iter)
@@ -645,7 +649,11 @@ static verdict ttp64_ipv4_external(struct xlation *state)
 
 	hdr4->version = 4;
 	hdr4->ihl = 5;
+#if LINUX_VERSION_AT_LEAST(6, 18, 0, 9999, 0)
+	hdr4->tos = flow4->flowi4_dscp;
+#else
 	hdr4->tos = flow4->flowi4_tos;
+#endif
 	hdr4->tot_len = cpu_to_be16(state->out.skb->len);
 	generate_ipv4_id(state, hdr4, hdr_frag);
 	hdr4->frag_off = xlat_frag_off(hdr_frag, state);
