@@ -1,7 +1,7 @@
 #ifndef SRC_USR_ARGP_XLATOR_TYPE_H_
 #define SRC_USR_ARGP_XLATOR_TYPE_H_
 
-#include "common/config.h"
+#include "common/types.h"
 
 void xt_set(xlator_type xt);
 xlator_type xt_get(void);
